pub struct PoolResponse {
pub assets: [Asset; 2],
pub total_share: Uint128,
}Fields
assets: [Asset; 2]Trait Implementations
Sourceimpl Clone for PoolResponse
impl Clone for PoolResponse
Sourcefn clone(&self) -> PoolResponse
fn clone(&self) -> PoolResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PoolResponse
impl Debug for PoolResponse
Sourceimpl<'de> Deserialize<'de> for PoolResponse
impl<'de> Deserialize<'de> for PoolResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for PoolResponse
impl JsonSchema for PoolResponse
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for PoolResponse
impl PartialEq for PoolResponse
Sourceimpl Serialize for PoolResponse
impl Serialize for PoolResponse
impl StructuralPartialEq for PoolResponse