pub struct ReverseSimulationResponse {
pub offer_amount: Uint128,
pub spread_amount: Uint128,
pub commission_amount: Uint128,
}Expand description
ReverseSimulationResponse returns reverse swap simulation response
Fields
offer_amount: Uint128spread_amount: Uint128commission_amount: Uint128Trait Implementations
Sourceimpl Clone for ReverseSimulationResponse
impl Clone for ReverseSimulationResponse
Sourcefn clone(&self) -> ReverseSimulationResponse
fn clone(&self) -> ReverseSimulationResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ReverseSimulationResponse
impl Debug for ReverseSimulationResponse
Sourceimpl<'de> Deserialize<'de> for ReverseSimulationResponse
impl<'de> Deserialize<'de> for ReverseSimulationResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ReverseSimulationResponse
impl JsonSchema for ReverseSimulationResponse
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreimpl StructuralPartialEq for ReverseSimulationResponse