pub struct StablePoolConfig {
pub amp: Decimal,
}Fields
amp: DecimalTrait Implementations
Sourceimpl Clone for StablePoolConfig
impl Clone for StablePoolConfig
Sourcefn clone(&self) -> StablePoolConfig
fn clone(&self) -> StablePoolConfig
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for StablePoolConfig
impl Debug for StablePoolConfig
Sourceimpl<'de> Deserialize<'de> for StablePoolConfig
impl<'de> Deserialize<'de> for StablePoolConfig
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for StablePoolConfig
impl JsonSchema for StablePoolConfig
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for StablePoolConfig
impl PartialEq for StablePoolConfig
Sourceimpl Serialize for StablePoolConfig
impl Serialize for StablePoolConfig
impl StructuralPartialEq for StablePoolConfig