pub struct StablePoolParams {
pub amp: u64,
}Fields
amp: u64Trait Implementations
Sourceimpl Clone for StablePoolParams
impl Clone for StablePoolParams
Sourcefn clone(&self) -> StablePoolParams
fn clone(&self) -> StablePoolParams
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for StablePoolParams
impl Debug for StablePoolParams
Sourceimpl<'de> Deserialize<'de> for StablePoolParams
impl<'de> Deserialize<'de> for StablePoolParams
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for StablePoolParams
impl JsonSchema for StablePoolParams
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for StablePoolParams
impl PartialEq for StablePoolParams
Sourceimpl Serialize for StablePoolParams
impl Serialize for StablePoolParams
impl StructuralPartialEq for StablePoolParams