pub struct SimulateSwapOperationsResponse {
pub amount: Uint128,
}Fields
amount: Uint128Trait Implementations
Sourceimpl Clone for SimulateSwapOperationsResponse
impl Clone for SimulateSwapOperationsResponse
Sourcefn clone(&self) -> SimulateSwapOperationsResponse
fn clone(&self) -> SimulateSwapOperationsResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for SimulateSwapOperationsResponse
impl<'de> Deserialize<'de> for SimulateSwapOperationsResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for SimulateSwapOperationsResponse
impl JsonSchema for SimulateSwapOperationsResponse
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for SimulateSwapOperationsResponse
impl PartialEq for SimulateSwapOperationsResponse
Sourcefn eq(&self, other: &SimulateSwapOperationsResponse) -> bool
fn eq(&self, other: &SimulateSwapOperationsResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for SimulateSwapOperationsResponse